@@ -35,21 +35,28 @@ connected=False
    server="SERVER",          // nome do servidor como definido no terminal
    timeout=TIMEOUT           // tempo de espera esgotado
 """
-def connect(account=None,passw=None):
+def connect(account=None,passw=None,mt5path=None):
 	#if not b3.connect():
 	#print(“Error on connection”, b3.last_error())
 	#exit():
     if account==None and passw==None:
-        res= mt5.initialize()
+        if mt5path==None:
+            res= mt5.initialize()
+        else:
+            res= mt5.initialize(mt5path)
     else:
         account=int(account)
-        res= mt5.initialize(login=account, password=passw)
+        if mt5path==None:
+            res= mt5.initialize(login=account, password=passw)
+        else:
+            res= mt5.initialize(mt5path,login=account, password=passw)
     global ac,path,datapath,commonDatapath,company,platform,connected
     if res!=True:
         if account==None:
-            print('Error trying to connect to last account!!')
+            print('Error trying to connect to last account!!', ' Error code:',mt5.last_error())
         else:
-            print('Error trying to connect to account: ',account)
+            print('Error trying to connect to account: ',account, ' Error code:',mt5.last_error())
+        return False
     info=mt5.account_info()
     if info.margin_so_mode !=mt5.ACCOUNT_MARGIN_MODE_RETAIL_NETTING:
         print("It is NOT netting, but B3 should be netting trade mode!! Error!!")  # B3 is Netting!!
@@ -74,6 +81,12 @@ def connect(account=None,passw=None):
         connected=True
     return res
 
+def terminalInfo():
+   if not connected:
+        print("In order to use this function, you must be connected to B3. Use function connect()")
+        return
+    term_info = mt5.terminal_info()
+    return term_info
 
 def accountInfo():
 #acc=b3.accountInfo()    # it returns a dictionary
@@ -156,6 +169,20 @@ def today(offset=None):
         dt=dt+timedelta(days=offset)
         return dt
 
+"""
+It returns the today datetime (hours=minutes=seconds=0)
+ You can define an offset in days.
+    today(1) returns tomorrow
+    today(-1) returns yesterday
+"""
+def now(hourOffset=None,minOffset=None):
+    dt=datetime.now(sptz)
+    if hourOffset!=None:
+        dt=dt+timedelta(hours=hourOffset)
+    if minOffset!=None:
+        dt=dt+timedelta(minutes=minOffset) 
+    return dt
+
 """
   It returns if the market is still open but just for closing orders.
      Note that markets can close in different times for different assets, therefore
@@ -213,11 +240,13 @@ def getSharesStep(assetId,money=None):
 def getBalance():
     return mt5.account_info().balance
 
-# Valor da posição total, saldo em reais mais valores correntes dos ativos (Balance+getPosition).
-def getTotalPosition():
-    return getPosition()+getBalance()
-
-def getPosition(symbolId=None):  # return the current value of assets (it does not include balance or margin)
+# Valor da posição total, saldo em reais mais valores correntes dos ativos 
+def getTotalPosition(symbolId=None):
+    pos=getPosition(symbolId)
+    if len(pos)>0:
+        return sum(pos['volume']*pos['price_current'])
+    else:
+        return 0.0
 #b3.getPosition( symbol_id) # return the current position in a given asset (symbol_id)
 #Examples:
 #b3.getPosition('PETR4')
@@ -229,14 +258,21 @@ def getPosition(symbolId=None):  # return the current value of assets (it does n
 #pos['price']  #current price of the asset
 # b3.getPosition(group='PETR*') # returns a list of positions that are part of the group
   #print("get position")
-  if not connected:
+
+def getPosition(symbolId=None):  # return the current value of assets (it does not include balance or margin)
+    if not connected:
         print("In order to use this function, you must be connected to B3. Use function connect()")
         return
-
-  if symbolId==None:
-      return mt5.positions_total()
-  else:
-      return mt5.positions_get(symbol=symbolId)
+    if symbolId==None:
+        positions=mt5.positions_get()
+    else:
+        positions=mt5.positions_get(symbol=symbolId)
+    if len(positions)>0:
+        df=pd.DataFrame(list(positions),columns=positions[0]._asdict().keys())
+        df=df[['symbol','profit','volume', 'price_open', 'price_current']]
+        return df
+    else:
+        return pd.DataFrame()
 
 
 
@@ -530,7 +566,20 @@ def getFirstPrice(bars):# argumento deve ser bars nao vazia, retorna erro se est
         print("In order to use this function, you must be connected to B3. Use function connect()")
         return
     return bars['open'][0]
-   
+
+def getMaxPrice(bars):# argumento deve ser bars nao vazia, retorna erro se estiver vazia
+    if not connected:
+        print("In order to use this function, you must be connected to B3. Use function connect()")
+        return
+    return max(bars['high']
+
+
+def getMinPrice(bars):# argumento deve ser bars nao vazia, retorna erro se estiver vazia
+    if not connected:
+        print("In order to use this function, you must be connected to B3. Use function connect()")
+        return
+    return max(bars['low']
+
 def getLastTime(bars): # argumento deve ser bars nao vazia, retorna erro se estiver vazia
     return bars['time'].iloc[-1]
 
