@@ -167,7 +167,9 @@ def executeOrders(orders,ops,dbars):
     sim_dates.append(getCurrTime(ops))
 
     txt=''
+    balance=b3.getBalance() 
     for asset in assets:
+        shares=b3.getShares(asset)
         order=getOrder(orders,asset)
         # send order
         if order!=None:
@@ -177,17 +179,15 @@ def executeOrders(orders,ops,dbars):
                     print('Error  : ',b3.getLastError())
             txt=txt+' '+asset+', '+ str(shares)+', '+str(getDeltaOrder(order))+';'
         else:
-            balance=b3.getBalance() 
-            shares=b3.getShares(asset)
             txt=txt+' '+asset+','+ str(shares)+', 0;'
             continue
-    balance=b3.getBalance() 
     total_in_shares=b3.getPosition()
     if ops['verbose']==True:
         msg=str(len(orders))+' order(s) in time('+str(sim_dates[-1])+' equity={:,.2f} balance={:,.2f} '+txt
         print(msg.format(balance+total_in_shares,balance))
     else:
-        print(len(orders),' order(s) in time(',sim_dates[-1],'). Use verbose=True for more information')
+        msg=str(len(orders))+' order(s) in time('+str(sim_dates[-1])+' equity={:,.2f} balance={:,.2f}. Use verbose=True for more information'
+        print(msg.format(balance+total_in_shares,balance))
     equityHist.append(balance+total_in_shares)
     balanceHist.append(balance)
     datesHist.append(sim_dates[-1])
@@ -241,36 +241,6 @@ def endedOps(ops):
 
 
 
-def runMultiTraders(traders,ops):
-    if traders==None: # or type(trader)!=b3.Trader:
-        print("Error! Traders should be a list of object of class mt5b3.Trader or its subclass")
-        return False
-    dbars=startOps(ops)
-    for trader in traders:
-        trader.setup(dbars)
-    if 'delay' in ops.keys():
-        delay=ops['delay']
-    else:
-        delay=0
-    if ops['verbose']:
-        print("Starting Operation at date/time=",sim_dates[0]," len=",len(sim_dates))
-    if ops['waitForOpen']:
-        while not b3.isMarketOpen():
-            print('Market is NOT open! we will wait until it is open...')
-            time.sleep(1)
-    while not endedOps(ops):
-        for trader in traders:
-            orders=trader.trade(ops,dbars)
-            executeOrders(orders,ops,dbars) # problema registro de ordem para multitraders
-        dbars=getCurrBars(ops,dbars)
-        time.sleep(delay)
-    print('End of operation saving equity file in ',ops['file'])
-    for trader in traders:
-        trader.ending(dbars)
-    df=saveEquityFile(ops) # problema para multitraders
-    return df
-
-
 
 def run(trader,ops):
     if trader==None: # or type(trader)!=b3.Trader:
